@@ -13,7 +13,7 @@ class Configuration(object):
 
     initialized = False  # Flag indicating config has been initialized
     verbose = 0
-    version = '2.6.6'
+    version = '2.7.0'
 
     all_bands = None
     attack_max = None
@@ -37,6 +37,7 @@ class Configuration(object):
     min_power = None
     no_deauth = None
     no_wps = None
+    no_nullpin = None
     num_deauths = None
     pmkid_timeout = None
     print_stack_traces = None
@@ -199,7 +200,7 @@ class Configuration(object):
         cls.use_bully = False  # Use bully instead of reaver
         cls.use_reaver = False  # Use reaver instead of bully
         cls.wps_pixie = True
-        cls.wps_nullpin = True
+        cls.wps_no_nullpin = True
         cls.wps_pin = True
         cls.wps_ignore_lock = False  # Skip WPS PIN attack if AP is locked.
         cls.wps_pixie_timeout = 300  # Seconds to wait for PIN before WPS Pixie attack fails
@@ -429,7 +430,7 @@ class Configuration(object):
                          'handshakes' % args.wordlist)
             elif os.path.isfile(args.wordlist):
                 cls.wordlist = args.wordlist
-                Color.pl('{+} {C}option:{W} using wordlist {G}%s{W} to crack WPA handshakes' % args.wordlist)
+                Color.pl('{+} {C}option:{W} using wordlist {G}%s{W} for cracking' % args.wordlist)
             elif os.path.isdir(args.wordlist):
                 cls.wordlist = None
                 Color.pl('{+} {C}option:{O} wordlist {R}%s{O} is a directory, not a file. Wifite will NOT attempt to '
@@ -472,28 +473,28 @@ class Configuration(object):
             # No WPS attacks at all
             cls.no_wps = args.no_wps
             cls.wps_pixie = False
-            cls.wps_nullpin = False
+            cls.wps_no_nullpin = True
             cls.wps_pin = False
             Color.pl('{+} {C}option:{W} will {O}never{W} use {C}WPS attacks{W} (Pixie-Dust/PIN) on targets')
 
         elif args.wps_pixie:
             # WPS Pixie-Dust only
             cls.wps_pixie = True
-            cls.wps_nullping = False
+            cls.wps_no_nullpin = True
             cls.wps_pin = False
             Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS Pixie-Dust attack{W} (no {O}PIN{W}) on targets')
 
         elif args.wps_no_nullpin:
             # WPS NULL PIN only
-            cls.wps_pixie = False
-            cls.wps_nullpin = True
-            cls.wps_pin = False
-            Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS NULL PIN attack{W} (no {O}PIN{W}) on targets')
+            cls.wps_pixie = True
+            cls.wps_no_nullpin = False
+            cls.wps_pin = True
+            Color.pl('{+} {C}option:{W} will {G}not{W} use {C}WPS NULL PIN attack{W} (no {O}PIN{W}) on targets')
 
         elif args.wps_no_pixie:
             # WPS PIN only
             cls.wps_pixie = False
-            cls.wps_nullpin = False
+            cls.wps_no_nullpin = True
             cls.wps_pin = True
             Color.pl('{+} {C}option:{W} will {G}only{W} use {C}WPS PIN attack{W} (no {O}Pixie-Dust{W}) on targets')
 
@@ -634,14 +635,11 @@ class Configuration(object):
         from .tools.airmon import Airmon
         if cls.interface is not None and Airmon.base_interface is not None:
             if not cls.daemon:
-                Color.pl('{!} {O}Note:{W} Leaving interface in {G}Monitor Mode{W}!')
-                if Airmon.use_ipiw:
-                    Color.pl('{!} To disable {G}Monitor Mode{W} when finished: ')
-                    Color.pl('{+}   {C}ip link set %s down{W}' % cls.interface)
-                    Color.pl('{+}   {C}iw %s set type managed{W}' % cls.interface)
-                    Color.pl('{+}   {C}ip link set %s up{W}\n' % cls.interface)
+                Color.pl('{!} {O}Note:{W} Leaving interface in Monitor Mode!')
+                if Airmon.isdeprecated:
+                    Color.pl('{!} To disable Monitor Mode when finished: {C}iwconfig %s mode managed{W}' % cls.interface)
                 else:
-                    Color.pl('{!} To disable Monitor Mode when finished: {C}airmon-ng stop %s{W}\n' % cls.interface)
+                    Color.pl('{!} To disable Monitor Mode when finished: {C}airmon-ng stop %s{W}' % cls.interface)
             else:
                 # Stop monitor mode
                 Airmon.stop(cls.interface)
