@@ -16,16 +16,12 @@ class CrackResultPMKID(CrackResult):
 
     def dump(self):
         if self.essid:
-            Color.pl('{+} %s: {C}%s{W}' %
-                ('Access Point Name'.rjust(19), self.essid))
+            Color.pl(f'{{+}} {"Access Point Name".rjust(19)}: {{C}}{self.essid}{{W}}')
         if self.bssid:
-            Color.pl('{+} %s: {C}%s{W}' %
-                ('Access Point BSSID'.rjust(19), self.bssid))
-        Color.pl('{+} %s: {C}%s{W}' %
-            ('Encryption'.rjust(19), self.result_type))
+            Color.pl(f'{{+}} {"Access Point BSSID".rjust(19)}: {{C}}{self.bssid}{{W}}')
+        Color.pl('{+} %s: {C}%s{W}' % ('Encryption'.rjust(19), self.result_type))
         if self.pmkid_file:
-            Color.pl('{+} %s: {C}%s{W}' %
-                ('PMKID File'.rjust(19), self.pmkid_file))
+            Color.pl('{+} %s: {C}%s{W}' % ('PMKID File'.rjust(19), self.pmkid_file))
         if self.key:
             Color.pl('{+} %s: {G}%s{W}' % ('PSK (password)'.rjust(19), self.key))
         else:
@@ -50,11 +46,11 @@ class CrackResultPMKID(CrackResult):
 
 
 if __name__ == '__main__':
-    w = CrackResultPMKID('AA:BB:CC:DD:EE:FF', 'Test Router', 'hs/pmkid_blah-123213.16800', 'abcd1234')
+    w = CrackResultPMKID('AA:BB:CC:DD:EE:FF', 'Test Router', 'hs/pmkid_blah-123213.22000', 'abcd1234')
     w.dump()
 
-    w = CrackResultPMKID('AA:BB:CC:DD:EE:FF', 'Test Router', 'hs/pmkid_blah-123213.16800', 'Key')
+    w = CrackResultPMKID('AA:BB:CC:DD:EE:FF', 'Test Router', 'hs/pmkid_blah-123213.22000', 'Key')
     print('\n')
     w.dump()
     w.save()
-    print(w.__dict__['bssid'])
+    print((w.__dict__['bssid']))
