@@ -20,6 +20,7 @@ class John(Dependency):
     def crack_handshake(handshake, show_command=False):
         john_file = HcxPcapngTool.generate_john_file(handshake, show_command=show_command)
 
+        key = None
         # Use `john --list=formats` to find if OpenCL or CUDA is supported.
         formats_stdout = Process(['john', '--list=formats']).stdout()
         if 'wpapsk-opencl' in formats_stdout:
@@ -30,7 +31,7 @@ class John(Dependency):
             john_format = 'wpapsk'
 
         # Crack john file
-        command = ['john', f'--format={john_format}', '--wordlist', Configuration.wordlist, john_file]
+        command = ['john', f'--format={john_format}', f'--wordlist={Configuration.wordlist}', john_file]
         if show_command:
             Color.pl('{+} {D}Running: {W}{P}%s{W}' % ' '.join(command))
         process = Process(command)
