@@ -116,7 +116,7 @@ class Tshark(Dependency):
             '-r', capfile,  # Path to cap file
             '-n',  # Don't resolve addresses
             # Extract beacon frames
-            '-Y', 'wlan.fc.type_subtype == 0x08 || wlan.fc.type_subtype == 0x05',
+            '-Y', '"wlan.fc.type_subtype == 0x08 || wlan.fc.type_subtype == 0x05"',
         ]
 
         tshark = Process(command, devnull=False)
