@@ -3,6 +3,7 @@
 
 import time
 
+
 class Timer(object):
     def __init__(self, seconds):
         self.start_time = time.time()
@@ -18,17 +19,17 @@ class Timer(object):
         return time.time() - self.start_time
 
     def __str__(self):
-        ''' Time remaining in minutes (if > 1) and seconds, e.g. 5m23s'''
+        """ Time remaining in minutes (if > 1) and seconds, e.g. 5m23s"""
         return Timer.secs_to_str(self.remaining())
 
     @staticmethod
     def secs_to_str(seconds):
-        '''Human-readable seconds. 193 -> 3m13s'''
+        """Human-readable seconds. 193 -> 3m13s"""
         if seconds < 0:
             return '-%ds' % seconds
 
         rem = int(seconds)
-        hours = int(rem / 3600)
+        hours = rem // 3600
         mins = int((rem % 3600) / 60)
         secs = rem % 60
         if hours > 0:
